from eth_abi import encode_abi

EMPTY_BYTES = encode_abi(["uint8"], [int(0)])


def univ2_expected_out_data():
    return EMPTY_BYTES


def curve_expected_out_data():
    return EMPTY_BYTES


def chainlink_expected_out_data(price_feed_addresses, reverses):
    return encode_abi(
        ["address[]", "bool[]"],
        [
            price_feed_addresses,
            reverses,
        ],
    )


def univ3_expected_out_data(swap_path, pool_fees):
    return encode_abi(["address[]", "uint24[]"], [swap_path, pool_fees])


def meta_expected_out_data(swap_path, expected_out_calculators, expected_out_data):
    return encode_abi(
        ["address[]", "address[]", "bytes[]"],
        [
            swap_path,
            expected_out_calculators,
            expected_out_data,
        ],
    )


def dynamic_slippage_price_checker_data(allowed_slippage_bips, expected_out_data):
    return encode_abi(
        ["uint256", "bytes"], [int(allowed_slippage_bips), expected_out_data]
    )


def fixed_slippage_price_checker_data(expected_out_data):
    return expected_out_data



from milkman_py.main import (
    univ2_expected_out_data,
    univ3_expected_out_data,
    curve_expected_out_data,
    chainlink_expected_out_data,
    meta_expected_out_data,
    fixed_slippage_price_checker_data,
    dynamic_slippage_price_checker_data,
)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['milkman_py']

package_data = \
{'': ['*']}

install_requires = \
['eth_abi==2.2.0']

setup_kwargs = {
    'name': 'milkman-py',
    'version': '0.1.0',
    'description': 'Python SDK for interacting with Milkman, a smart contract system that allows smart contracts (incl. Gnosis Safes) to swap assets through the CoW protocol.',
    'long_description': '',
    'author': 'charlesndalton',
    'author_email': 'charles.n.dalton@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
